@@ -17,7 +17,7 @@ from womg_core.network.tlt_network_model import TLTNetworkModel
 from womg_core.utils.utility_functions import read_edgelist
 
 
-DEFAULT_GRAPH = pathlib.Path(os.path.abspath(womg_core.__file__).replace('/womg/__init__.py',
+DEFAULT_GRAPH = pathlib.Path(os.path.abspath(womg_core.__file__).replace('/womg_core/__init__.py',
                              ''))/ "womgdata" / "graph" / "lesmiserables" / "lesmiserables_edgelist.txt"
 
 class TN(TLTNetworkModel):
@@ -110,6 +110,8 @@ class TN(TLTNetworkModel):
         if isinstance(self._graph, nx.classes.graph.Graph):
             self.nx_obj = self._graph.copy()
             self.directed = self.nx_obj.is_directed()
+            if not self.directed:
+                self.nx_obj = self.nx_obj.to_directed()
             self._weighted = nx.is_weighted(self.nx_obj)
         elif self._graph is None:
             print('No graph path provided \n',
@@ -123,6 +125,11 @@ class TN(TLTNetworkModel):
             self.nx_obj, self.mapping = read_edgelist(path=self._graph,
                                                       weighted=self._weighted,
                                                       directed=self.directed)
+        ##### check coherence of parameters ###
+        if self._numb_topics > self.nx_obj.number_of_nodes():
+            raise ValueError("Number of nodes must be >= number of topics.")
+
+
         if self._godnode_strength is not None:
             self.set_godnode_links()
         self.set_interests(int_mode)
@@ -165,18 +172,13 @@ class TN(TLTNetworkModel):
             for node in self._progress_bar(self.nx_obj.nodes()):
                 rand_num = np.abs(np.random.randn())
                 god_node_links.append((-1, node, rand_num))
-                if not self.directed:
-                    god_node_links.append((node, -1, rand_num))
             self.nx_obj.add_weighted_edges_from(god_node_links)
         if isinstance(nodes, int):
             self.nx_obj.add_weighted_edges_from([(-1, nodes, weight)])
-            if not self.directed:
-                self.nx_obj.add_weighted_edges_from([(nodes, -1, weight)])
         if isinstance(nodes, collections.Iterable):
             for node in self._progress_bar(nodes):
                 self.nx_obj.add_weighted_edges_from([(-1, node, weight)])
-                if not self.directed:
-                    self.nx_obj.add_weighted_edges_from([(node, -1, weight)])
+
 
     def set_interests(self, int_mode):
         '''
